#!/usr/bin/env node
"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = __importStar(require("fs-extra"));
var glob = __importStar(require("glob"));
var path = __importStar(require("path"));
var commander_1 = __importDefault(require("commander"));
var program = new commander_1.default.Command("glob-test-ids");
var packageJson = JSON.parse(fs.readFileSync(path.join(__dirname, "..", "package.json")).toString());
program.version(packageJson.version);
program
    .requiredOption("-i, --ids-location <location>", "glob pattern of id files")
    .requiredOption("-o, --output <output>", "Output file");
program.parse(process.argv);
exports.globTestIds = function () {
    try {
        var allIds = glob
            .sync(path.join(process.cwd(), program.idsLocation))
            .map(function (filename) { return ({
            filename: filename,
            file: fs.readFileSync(filename, "utf8")
        }); })
            .map(function (_a) {
            var filename = _a.filename, file = _a.file;
            return ({
                filename: filename,
                file: JSON.parse(file)
            });
        })
            .reduce(function (ids, _a) {
            var filename = _a.filename, file = _a.file;
            file.forEach(function (testId) {
                if (testId in ids) {
                    throw new Error("Duplicate test id " + testId + " in " + filename);
                }
                ids[testId] = testId;
            });
            return ids;
        }, {});
        fs.mkdirpSync(path.dirname(program.output));
        var outFile = path.join(process.cwd(), program.output);
        fs.writeFileSync(outFile, JSON.stringify(allIds, null, 2));
        console.log(Object.keys(allIds).length + " test ids written to " + outFile);
        process.exit(0);
    }
    catch (e) {
        console.error(e);
        process.exit(1);
    }
};
exports.globTestIds();
